==> V01.11.zip: tweet_live-V01.11/web/enmi2011/config.php <==
<?php
$config = array(
   	'hashtag'    => '#enmi',
   	'date'   => '19.12.2011',
   	'heure'   => '10h00-19h30',
   	'place'   => 'Grande salle - Centre Pompidou',

   	'title' => "Entretiens du nouveau monde industriel 2011 ",
	'abstract'   => "<b>« Les Technologies de la confiance »</b><br/>le 19/12/2011 de 10h00 à 19h30<br/>@ Grande salle (Centre Pompidou) - entrée libre et gratuite",
//   	'abstract'   => "<b>Nouvelle forme d'éditorialisation</b>,<br/><b>Entre pédagogie, information et entertainment : le Web-doc et au-delà,</b><br/>le 01/12/2011 de 17h30 à 19h30<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "
	<strong>19 décembre 2011</strong><br/>

	<strong>SESSION 1 – HISTOIRE ET ANTHROPOLOGIE DE LA CONFIANCE</strong><br/>
	Etude des perspectives philosophiques, historiques, théologiques et  anthropologiques sur la confiance, pensée dans le contexte contemporain  du numérique et de la crise économico-politique, ou en relation avec le  développement des processus de grammatisation et des dispositifs  d’enregistrement des traces, depuis la crise induite par l’imprimerie  jusqu’au développement du monde numérique contemporain.<br/><br/>

	Intervenants : Bernard Stiegler (IRI / Ars Industrialis), Michel  Guérin (Univ. Aix-Marseille), Cynthia Fleury (American University,  Paris), Paul Jorion (Chroniqueur Le Monde Economie)<br/><br/>

	<strong>SESSION 2 - SCIENCE, CONFIANCE, CALCUL ET SAVOIR</strong><br/>
	La confiance est-elle réductible au calculable (peut-elle se passer  d’un incalculable) ? Est-elle réductible à une évaluation quantifiée des  risques (financiers, sanitaires, nucléaires, technologiques, etc.) ou  ne ressortit-elle pas de principes tout à fait différents, nécessitant  de reconsidérer de nos jours et en totalité la question des savoirs  démocratiques qu’une expertise technocratisée à l’extrême aurait  discrédités et détruits ? Quelles issues peuvent-elles être envisagées  pour surmonter la défiance qui s’installe entre société et sciences –  elles-mêmes de plus en plus souvent apparentées à une logique de  développement dont les effets pervers et les limites semblent s’étaler  tout à coup sous nos yeux ? Peut-on imaginer que les technologies de la  traçabilité soient mises au service d’un nouvel âge démocratique  des  savoirs ?<br/><br/>

	Intervenants : Hidetaka Ishida (Univ. de Tokyo), Jean-Pierre Dupuy (,  Alain Mille (Univ. Lyon 1 – Liris), Judith Simon (Institut Jean Nicod /  Institut de Technologie de Karlsruhe)<br/><br/>

	<strong>SESSION 3 – ECONOMIE et  MARKETING</strong><br/>
	Dans le contexte décillant de la crise actuelle, on parle de plus en  plus de nouveaux modèles de marketing, de publicité, mais aussi de  monnaie. Le marketing en réseau ne reconstituent-ils pas, cependant, et  en les aggravants, les effets ravageurs du consumérisme apparu au XX<sup>e</sup> siècle ? Au-delà du simple calcul des risques proprement une ingénierie  de la confiance et de nouveaux espaces tentant de la recréer dits se  sont développés, en particulier sur le Web. Quelles difficultés  entendent-ils dépasser ? Quelles solutions proposent-ils et que penser  de la demande sous-jacente qu’ils expriment ? A l’heure de la menace  d’éclatement de la zone euro, un nouveau commerce – qui pourrait même se  fonder sur de nouvelles formes de monnaies – est-il en train de  s’inventer ?<br/><br/>

	Intervenants : Patrick Viveret, Laurence Fontaine (CNRS), Serge Perez (Les Ateliers Corporate), Marc-André Feffer (La Poste)<br/><br/>

	<strong>19:00-22:00</strong><br/>
	Carrefour des possibles de la Fing, présentation de projets de jeunes start-up innovantes<br/><br/>

	<strong> </strong><strong>20 décembre 2011</strong><strong></strong><br/>

	<strong>SESSION 4 – </strong><strong>TECHNOLOGIES et DESIGN de la CONFIANCE</strong><br/>
	La <em>fabrication</em> de la confiance conduit-elle à la défiance (telles les <em>cartes de fidélité</em>) ?  Quelles sont les stratégies des marques et du marketing tribal sur le  Web? Les questions posées par le contrôle des données personnelles et le  profilage refreinent-ils le développement de systèmes de contribution?  Les approches cognitivistes peuvent-elles nous apprendre quelque chose  sur les conditions de constitution de la confiance ?<br/><br/>

	Intervenants : Eddie Soulier (Laboratoire Tech-CICO, Univ. de  Technologie de Troyes), Nicolas Auray (Télécom ParisTech), Hugo Zaragoza  (Websays)<br/>
	12:00-12:35 Daniel Kaplan – Présentation des travaux récents sur la confiance conduits par la Fing<br/>
	12:35-13:15 – Alain Cadix- Présentation des travaux des élèves de  l’ENSCI-Les Ateliers réalisés dans le cadre de Users Studio avec le  concours de la Fing.<br/><br/>
	
	<strong>SESSION 5 - C</strong><strong>ONFIANCE ET POLITIQUE</strong><br/>

	Dans quelle mesure les <em>public data</em> – qui viennent modifier  en profondeur le rapport public/privé – sont-elles un enjeu pour les  puissances publiques (collectivités territoriales et nationales,  organisations internationales) ou privées (entreprises) désireuses de  rétablir la confiance ? Ne risquent-elles pas d’aboutir à l’inverse de  ce pour quoi certains y placent leurs meilleurs espoirs – constituant  comme c’est apparu dans certaines expériences une soumission du secteur  public aux intérêts privés ? Qu’en est-il des exceptions sur les données  sensibles, dans le contexte récent des dossiers Wikileaks ? Et qu’est  devenue la notion de vie privée au moment où « le privé » est devenu  synonyme du profitable, et l’opposé de l’intimité – sinon la police  privée – ?<br/><br/>

	Intervenants : Valérie Peugeot (Orange Labs) Kieron O’Hara (Univ. de  Southampton, GB), Albert Ogien (CNRS /EHESS) , Catherine Fieschi  (Couterpoint), Bernard Umbrecht<br/>

	<strong>Allocution de fin de colloque : Ulrich Beck </strong>.",
   	'link' => 'http://www.iri.centrepompidou.fr',
   	'islive'     => true,
   	'keywords'   => 'editorialisation, iri',
   	'rep' => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.sens-public.org' class='footerLink' target='_blank'>Sens Public</a> | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/big_visuel_edito.jpg',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-enmi2011.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-enmi2011.jpg', // 270 × 150 pixels

 	'archive_title' => "le Web-doc et au-delà",
 	'archive_description' => 'par <a href="http://www.sens-public.org" target="_blank">Sens Public</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou le jeudi 1 décembre 2011 17:30 - 19:30',

    // After the event
	'metadata'    => "http://www.iri.centrepompidou.fr/dev/ldt/ldtplatform/ldt/cljson/id/0911926e-093a-11e1-996f-00145ea49a02",
	'duration'   => 8357400,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 700,
	'player_width'  => 650,
	'player_height' => 488,
	
    // New Tweet live parameters
    'use_tweetcast' => true,
    'js_config' => "
    var connect_type = 'gevent',
    source_address = 'http://polemictweet.com/tweetcast-proxy.php',
    tracking_keywords = [ \"#enmi\" ],
    suggested_keywords = [
        \"confiance\",
        \"croyance\",
        \"crédit\",
        \"trace\",
        \"foi\",
        \"risque\",
        \"assurance\",
        \"démocratie\",
        \"expertise\",
        \"catastrophe\",
        \"transparence\",
        \"politique\"
    ],
    annotations = {
        \"default\" : {
            \"colors\" : {
                \"h\" : 0,
                \"s\" : 0
            }
        },
        \"positive\" : {
            \"display_name\" : \"++\",
            \"keywords\" : [ /\\+\\+/ ],
            \"colors\" : {
                \"h\" : .3,
                \"s\" : .65
            }
        },
        \"negative\" : {
            \"display_name\" : \"--\",
            \"keywords\" : [ /\\-\\-/ ],
            \"colors\" : {
                \"h\" : 0,
                \"s\" : .8
            }
        },
        \"reference\" : {
            \"display_name\" : \"==\",
            \"keywords\" : [ /\\=\\=/ ],
            \"colors\" : {
                \"h\" : .16,
                \"s\" : .8
            }
        },
        \"question\" : {
            \"display_name\" : \"??\",
            \"keywords\" : [ /\\?\\?/ ],
            \"colors\" : {
                \"h\" : .6,
                \"s\" : .8
            }
        }
    }"
    
    
);

==> V01.57.zip: tweet_live-V01.57/web/enmi2011/config.php <==
<?php
$config = array(
   	'hashtag'    => '#enmi',
   	'date'   => '19.12.2011',
   	'heure'   => '10h00-19h30',
   	'place'   => 'Grande salle - Centre Pompidou',

   	'title' => "Entretiens du nouveau monde industriel 2011 ",
	'abstract'   => "<b>« Les Technologies de la confiance »</b><br/>le 19/12/2011 de 10h00 à 19h30<br/>@ Grande salle (Centre Pompidou) - entrée libre et gratuite",
//   	'abstract'   => "<b>Nouvelle forme d'éditorialisation</b>,<br/><b>Entre pédagogie, information et entertainment : le Web-doc et au-delà,</b><br/>le 01/12/2011 de 17h30 à 19h30<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "
	<strong>19 décembre 2011</strong><br/>

	<strong>SESSION 1 – HISTOIRE ET ANTHROPOLOGIE DE LA CONFIANCE</strong><br/>
	Etude des perspectives philosophiques, historiques, théologiques et  anthropologiques sur la confiance, pensée dans le contexte contemporain  du numérique et de la crise économico-politique, ou en relation avec le  développement des processus de grammatisation et des dispositifs  d’enregistrement des traces, depuis la crise induite par l’imprimerie  jusqu’au développement du monde numérique contemporain.<br/><br/>

	Intervenants : Bernard Stiegler (IRI / Ars Industrialis), Michel  Guérin (Univ. Aix-Marseille), Cynthia Fleury (American University,  Paris), Paul Jorion (Chroniqueur Le Monde Economie)<br/><br/>

	<strong>SESSION 2 - SCIENCE, CONFIANCE, CALCUL ET SAVOIR</strong><br/>
	La confiance est-elle réductible au calculable (peut-elle se passer  d’un incalculable) ? Est-elle réductible à une évaluation quantifiée des  risques (financiers, sanitaires, nucléaires, technologiques, etc.) ou  ne ressortit-elle pas de principes tout à fait différents, nécessitant  de reconsidérer de nos jours et en totalité la question des savoirs  démocratiques qu’une expertise technocratisée à l’extrême aurait  discrédités et détruits ? Quelles issues peuvent-elles être envisagées  pour surmonter la défiance qui s’installe entre société et sciences –  elles-mêmes de plus en plus souvent apparentées à une logique de  développement dont les effets pervers et les limites semblent s’étaler  tout à coup sous nos yeux ? Peut-on imaginer que les technologies de la  traçabilité soient mises au service d’un nouvel âge démocratique  des  savoirs ?<br/><br/>

	Intervenants : Hidetaka Ishida (Univ. de Tokyo), Jean-Pierre Dupuy (,  Alain Mille (Univ. Lyon 1 – Liris), Judith Simon (Institut Jean Nicod /  Institut de Technologie de Karlsruhe)<br/><br/>

	<strong>SESSION 3 – ECONOMIE et  MARKETING</strong><br/>
	Dans le contexte décillant de la crise actuelle, on parle de plus en  plus de nouveaux modèles de marketing, de publicité, mais aussi de  monnaie. Le marketing en réseau ne reconstituent-ils pas, cependant, et  en les aggravants, les effets ravageurs du consumérisme apparu au XX<sup>e</sup> siècle ? Au-delà du simple calcul des risques proprement une ingénierie  de la confiance et de nouveaux espaces tentant de la recréer dits se  sont développés, en particulier sur le Web. Quelles difficultés  entendent-ils dépasser ? Quelles solutions proposent-ils et que penser  de la demande sous-jacente qu’ils expriment ? A l’heure de la menace  d’éclatement de la zone euro, un nouveau commerce – qui pourrait même se  fonder sur de nouvelles formes de monnaies – est-il en train de  s’inventer ?<br/><br/>

	Intervenants : Patrick Viveret, Laurence Fontaine (CNRS), Serge Perez (Les Ateliers Corporate), Marc-André Feffer (La Poste)<br/><br/>

	<strong>19:00-22:00</strong><br/>
	Carrefour des possibles de la Fing, présentation de projets de jeunes start-up innovantes<br/><br/>

	<strong> </strong><strong>20 décembre 2011</strong><strong></strong><br/>

	<strong>SESSION 4 – </strong><strong>TECHNOLOGIES et DESIGN de la CONFIANCE</strong><br/>
	La <em>fabrication</em> de la confiance conduit-elle à la défiance (telles les <em>cartes de fidélité</em>) ?  Quelles sont les stratégies des marques et du marketing tribal sur le  Web? Les questions posées par le contrôle des données personnelles et le  profilage refreinent-ils le développement de systèmes de contribution?  Les approches cognitivistes peuvent-elles nous apprendre quelque chose  sur les conditions de constitution de la confiance ?<br/><br/>

	Intervenants : Eddie Soulier (Laboratoire Tech-CICO, Univ. de  Technologie de Troyes), Nicolas Auray (Télécom ParisTech), Hugo Zaragoza  (Websays)<br/>
	12:00-12:35 Daniel Kaplan – Présentation des travaux récents sur la confiance conduits par la Fing<br/>
	12:35-13:15 – Alain Cadix- Présentation des travaux des élèves de  l’ENSCI-Les Ateliers réalisés dans le cadre de Users Studio avec le  concours de la Fing.<br/><br/>
	
	<strong>SESSION 5 - C</strong><strong>ONFIANCE ET POLITIQUE</strong><br/>

	Dans quelle mesure les <em>public data</em> – qui viennent modifier  en profondeur le rapport public/privé – sont-elles un enjeu pour les  puissances publiques (collectivités territoriales et nationales,  organisations internationales) ou privées (entreprises) désireuses de  rétablir la confiance ? Ne risquent-elles pas d’aboutir à l’inverse de  ce pour quoi certains y placent leurs meilleurs espoirs – constituant  comme c’est apparu dans certaines expériences une soumission du secteur  public aux intérêts privés ? Qu’en est-il des exceptions sur les données  sensibles, dans le contexte récent des dossiers Wikileaks ? Et qu’est  devenue la notion de vie privée au moment où « le privé » est devenu  synonyme du profitable, et l’opposé de l’intimité – sinon la police  privée – ?<br/><br/>

	Intervenants : Valérie Peugeot (Orange Labs) Kieron O’Hara (Univ. de  Southampton, GB), Albert Ogien (CNRS /EHESS) , Catherine Fieschi  (Couterpoint), Bernard Umbrecht<br/>

	<strong>Allocution de fin de colloque : Ulrich Beck </strong>.",
   	'link' => 'http://www.iri.centrepompidou.fr',
   	'islive'     => true,
   	'keywords'   => 'editorialisation, iri',
   	'rep' => basename(__DIR__),
    'partenaires'=> "<a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'> IRI </a>
		 |  <a href='http://www.ensci.fr/' class='footerLink' target='_blank' > ENSCI  </a>
		 |  <a href='http://www.capdigital.com/' class='footerLink' target='_blank' > Cap Digital  </a>
		 |  <a href='http://fing.org/' class='footerLink' target='_blank' > La Fing  </a>
		 |  <a href='http://www.alcatel-lucent.com/fr/' class='footerLink' target='_blank' > Alcatel-Lucent </a>
		 |  <a href='http://www.institut-telecom.fr/' class='footerLink' target='_blank' > Institut Telecom  </a>",

    'client_visual' => 'images/big_visuel_edito.jpg',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-enmi2011.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-enmi2011.jpg', // 270 × 150 pixels

 	'archive_title' => "le Web-doc et au-delà",
 	'archive_description' => 'par <a href="http://www.sens-public.org" target="_blank">Sens Public</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou le jeudi 1 décembre 2011 17:30 - 19:30',

    // After the event
    // http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/f1a17368-2bc8-11e1-b21a-00145ea49a02
    // ENMI 2011 - 1 - HISTOIRE ET ANTHROPOLOGIE DE LA CONFIANCE
    // 10398000
    // http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/a77eacdc-2bce-11e1-93ae-00145ea49a02
    // ENMI 2011 - 2 - SCIENCE, CONFIANCE, CALCUL ET SAVOIR
    // 7958065
    // http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/0786a9ca-2bd1-11e1-8b49-00145ea49a02
    // ENMI 2011 - 3 - ECONOMIE et  MARKETING
    // 8444451
    // http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/bd9638ce-2be1-11e1-b24c-00145ea49a02
    // ENMI 2011 - 4 - Carrefour des possibles
    // 6486345
    // http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/b8295a96-2be2-11e1-a83f-00145ea49a02
    // ENMI 2011 - 5 - TECHNOLOGIES et DESIGN de la CONFIANCE
    // 6002333
    // http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/3c2f1186-2be4-11e1-91a8-00145ea49a02
    // ENMI 2011 - 6 - CONFIANCE ET POLITIQUE 1
    // 5973314
    // http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/8ec10902-2be6-11e1-a635-00145ea49a02
    // ENMI 2011 - 7 - CONFIANCE ET POLITIQUE 2
    // 16158670
	'select_width' => 285,
	'metadata'    => array(
	    'enmi2011_1'=>array('url'=>'http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/f1a17368-2bc8-11e1-b21a-00145ea49a02', 'duration'=>10398000, 'display'=>'HISTOIRE ET ANTHROPOLOGIE DE LA CONFIANCE'),
		'enmi2011_2'=>array('url'=>'http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/a77eacdc-2bce-11e1-93ae-00145ea49a02', 'duration'=>7958065, 'display'=>'SCIENCE, CONFIANCE, CALCUL ET SAVOIR'),
		'enmi2011_3'=>array('url'=>'http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/0786a9ca-2bd1-11e1-8b49-00145ea49a02', 'duration'=>8444451, 'display'=>'ECONOMIE et  MARKETING'),
		'enmi2011_4'=>array('url'=>'http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/bd9638ce-2be1-11e1-b24c-00145ea49a02', 'duration'=>6486345, 'display'=>'Carrefour des possibles'),
		'enmi2011_5'=>array('url'=>'http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/b8295a96-2be2-11e1-a83f-00145ea49a02', 'duration'=>6002333, 'display'=>'TECHNOLOGIES et DESIGN de la CONFIANCE'),
		'enmi2011_6'=>array('url'=>'http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/3c2f1186-2be4-11e1-91a8-00145ea49a02', 'duration'=>5973314, 'display'=>'CONFIANCE ET POLITIQUE 1'),
		'enmi2011_7'=>array('url'=>'http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/8ec10902-2be6-11e1-a635-00145ea49a02', 'duration'=>16158670, 'display'=>'CONFIANCE ET POLITIQUE 2'),
	),
	'duration'   => 8357400,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 700,
	'player_width'  => 650,
	'player_height' => 488,
	
    // New Tweet live parameters
    'knowtex_url' => "http://labs.knowtex.com/enmi2011/?mapOnly#carto",
    'use_tweetcast' => true,
    'js_config' => "
    tracking_keywords = [ '#enmi' ],
    suggested_keywords = [
        'confiance',
        'croyance',
        'crédit',
        'trace',
        'foi',
        'risque',
        'assurance',
        'démocratie',
        'expertise',
        'catastrophe',
        'transparence',
        'politique'
    ]"
    
    
);
